flutter_furigana_renderer library
Classes
- FuriganaChar
- Represents a single unit of text, which may or may not have furigana. This class is part of the public API.
- FuriganaHtmlParser
- FuriganaParser
- FuriganaText
- A widget that renders Japanese text with furigana, supporting line wrapping and tap events on individual characters.
- FuriganaWord
- RenderFurigana